#include "clockwidget.h"

#include <QPainter>

ClockWidget::ClockWidget( QWidget * parent, const QString background_file_name ) : QWidget( parent )
{
	background_ = std::make_shared<QPixmap>( background_file_name );
	assert( background_->width() == background_->height() ); // we assume only a square image
}

ClockWidget::~ClockWidget()
{

}

QSize ClockWidget::sizeHint() const
{
	return QSize( background_->width(), background_->height() );
}
QSize ClockWidget::minimumSizeHint() const
{
	return QSize( 100, 100 );
}

void ClockWidget::paintEvent( QPaintEvent * event )
{
	QPainter painter( this ); // performs low-level painting on widget
	// set the given render hints on the painter
	painter.setRenderHint( QPainter::Antialiasing, true );
	painter.setRenderHint( QPainter::TextAntialiasing, true );
	painter.setRenderHint( QPainter::SmoothPixmapTransform, true );
	painter.setRenderHint( QPainter::HighQualityAntialiasing, true );

	// get the diameter and the radius of the circle inscribed in the widget's area.
	const float d = float( std::min( rect().width(), rect().height() ) );
	const float r = d * 0.5f;
	// get the center of the canvas	
	const QPoint center = rect().center();
	// get the top-left corner of the background
	const QPoint tl = center - QPoint( r, r );

	// draw the wall clock's background
	painter.drawPixmap( QRect( tl.x(), tl.y(), d, d ), *background_.get() );
}
